@@ -991,13 +991,7 @@ class PonLink:
     @rx_power.setter
     def rx_power(self, value):
         if value is not None:
-            if value >= 0 and value <= 100:
-                self.pb.rx_power = value
-            elif self.errctx:
-                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
-                                'Invalid value for NetworkElement.PonLink.rx_power',
-                                value=value,
-                                metric_name='NetworkElement.PonLink.rx_power')
+            self.pb.rx_power = value
         else:
             self.pb.ClearField('rx_power')
 
@@ -1008,13 +1002,7 @@ class PonLink:
     @tx_power.setter
     def tx_power(self, value):
         if value is not None:
-            if value >= 0 and value <= 100:
-                self.pb.tx_power = value
-            elif self.errctx:
-                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
-                                'Invalid value for NetworkElement.PonLink.tx_power',
-                                value=value,
-                                metric_name='NetworkElement.PonLink.tx_power')
+            self.pb.tx_power = value
         else:
             self.pb.ClearField('tx_power')
 
