@@ -594,6 +594,12 @@ class TestNetworkElementUpdate(unittest.TestCase):
         link.mac_address = '0a:00:00:0d:0e:0f'
         self.assertEqual(link.mac_address, '0a:00:00:0d:0e:0f')
 
+        self.assertEqual(link.oper_up, None)
+        link.oper_up = False
+        self.assertEqual(link.oper_up, False)
+        link.oper_up = None
+        self.assertEqual(link.oper_up, None)
+
         link.errctx = network_element_update.ErrorContext()
         self.assertEqual(link.in_octets, None)
         link.in_octets = pow(2, 31) + 1
